package com.ynet.life.loaf.action;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.gene.data.IndexedCollection;
import com.ynet.gene.data.KeyedCollection;
import com.ynet.life.action.LifeJDBCAction;
import com.ynet.life.base.LifeDBAccess;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.loaf.DataMappingProvider;
import java.sql.Connection;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;
import java.util.StringTokenizer;

/* loaded from: com_ynet_life_loaf_action.jar:com/ynet/life/loaf/action/QueryDataDetailBatchAction.class */
public class QueryDataDetailBatchAction extends LifeJDBCAction {
    private static final String FIELD_SEPERATOR = "||";
    private String businessCodeField;
    private String businessCode;
    private String iCollName;
    private List copyFields;
    private boolean throwException = true;

    public String execute(Context context) throws GENEException {
        Connection connection = null;
        try {
            try {
                String currentBusinessCode = this.businessCodeField != null ? (String) context.get(this.businessCodeField) : this.businessCode;
                IndexedCollection inputIColl = (IndexedCollection) context.get(this.iCollName);
                int size = inputIColl.size();
                if (size == 0) {
                    LifeDBAccess.releaseConnection(getDataSource(), (Connection) null);
                    return "0";
                }
                Trace.logDebug("LOAF", String.valueOf(currentBusinessCode) + "批量明细查询开始");
                connection = LifeDBAccess.getConnection(getDataSource());
                for (int i = 0; i < size; i++) {
                    KeyedCollection kColl = (KeyedCollection) inputIColl.get(i);
                    copyFieldsIntoKeyedCollection(context, kColl);
                    DataMappingProvider.fillTableDataIntoContext(connection, currentBusinessCode, kColl);
                }
                Trace.logDebug("LOAF", String.valueOf(currentBusinessCode) + "批量明细查询结束");
                LifeDBAccess.releaseConnection(getDataSource(), connection);
                return "0";
            } catch (TranFailException ex) {
                Trace.logError("LOAF", String.valueOf(ex.getErrorCode()) + "：" + ex.getMessage(), ex);
                handleException(context, ex, this.throwException);
                LifeDBAccess.releaseConnection(getDataSource(), connection);
                return "0";
            } catch (SQLException ex2) {
                Trace.logError("LOAF", ex2.getMessage(), ex2);
                handleException(context, new TranFailException("EBLN0000", ex2), this.throwException);
                LifeDBAccess.releaseConnection(getDataSource(), connection);
                return "0";
            }
        } catch (Throwable th) {
            LifeDBAccess.releaseConnection(getDataSource(), connection);
            throw th;
        }
    }

    private void copyFieldsIntoKeyedCollection(Context context, KeyedCollection kColl) {
        if (this.copyFields != null) {
            for (String fieldName : this.copyFields) {
                kColl.put(fieldName, context.get(fieldName));
            }
        }
    }

    public void setBusinessCodeField(String businessCodeField) {
        this.businessCodeField = businessCodeField;
    }

    public void setBusinessCode(String businessCode) {
        this.businessCode = businessCode;
    }

    public void setICollName(String collName) {
        this.iCollName = collName;
    }

    public void setThrowException(String throwException) {
        this.throwException = Boolean.valueOf(throwException).booleanValue();
    }

    public void setCopyFields(String inputFields) {
        List result = new ArrayList();
        StringTokenizer toke = new StringTokenizer(inputFields, FIELD_SEPERATOR);
        while (toke.hasMoreElements()) {
            String input = ((String) toke.nextElement()).trim();
            result.add(input);
        }
        this.copyFields = result;
    }
}
